<?php

namespace Student\Student\Http\Controllers;

use App\Http\Controllers\PublicController as CMSPublicController;
use Student\Student\Interfaces\KeyRepositoryInterface;

class KeyPublicController extends CMSPublicController
{
    /**
     * Constructor.
     *
     * @param type \Student\Key\Interfaces\KeyRepositoryInterface $key
     *
     * @return type
     */
    public function __construct(KeyRepositoryInterface $key)
    {
        $this->repository = $key;
        parent::__construct();
    }

    /**
     * Show key's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $keys = $this->repository->scopeQuery(function($query){
            return $query->orderBy('id','DESC');
        })->paginate();

        return $this->theme->of('student::public.key.index', compact('keys'))->render();
    }

    /**
     * Show key.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $key = $this->repository->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        return $this->theme->of('student::public.key.show', compact('key'))->render();
    }
}
